==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/mk.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "mk", 
    "plural-forms": "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "%(color)sмаица", 
    "%(color)sмаици"
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "%(num)dставка", 
    "%(num)dставки"
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "%(num)dнедостасува превод", 
    "%(num)dнедостасуваат преводи"
  ], 
  "Add Filter": [
    null, 
    "Додади филтер"
  ], 
  "An Error Occurred": [
    null, 
    "Се појави грешка"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Дали сте сигурни дека сакате да ја извршите оваа активност?"
  ], 
  "Cancel": [
    null, 
    "Откажете"
  ], 
  "Confirm": [
    null, 
    "Потврди"
  ], 
  "Could not load view": [
    null, 
    "Не може да се вчита приказ"
  ], 
  "DataProxy returned an error": [
    null, 
    "Податочното прокси врати грешка"
  ], 
  "DataStore returned an error": [
    null, 
    "Податочното складиште врати грешка"
  ], 
  "Edit": [
    null, 
    "Уредете"
  ], 
  "Failed to load data API information": [
    null, 
    "Не успеаа да се вчитаат информациите за API на податоци"
  ], 
  "File": [
    null, 
    "Датотека"
  ], 
  "Filters": [
    null, 
    "Филтри"
  ], 
  "Follow": [
    null, 
    "Следете"
  ], 
  "Graph": [
    null, 
    "График"
  ], 
  "Grid": [
    null, 
    "Мрежа"
  ], 
  "Hide": [
    null, 
    "Сокријте"
  ], 
  "Image": [
    null, 
    "Слика"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "Влезот е премногу краток, мора да биде најмалку еден знак", 
    "Влезот е премногу краток, мора да биде најмалку %(num)d знак"
  ], 
  "Link": [
    null, 
    "Линк"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Поврзете со линк на интернет (исто така можете да поврзете со API)"
  ], 
  "Loading...": [
    null, 
    "Се вчитува..."
  ], 
  "Map": [
    null, 
    "Мапа"
  ], 
  "No matches found": [
    null, 
    "Не се пронајдени совпаѓања"
  ], 
  "Please Confirm Action": [
    null, 
    "Ве молиме потврдете ја активноста"
  ], 
  "Remove": [
    null, 
    "Избриши"
  ], 
  "Resource uploaded": [
    null, 
    "Ресурсот е прикачен"
  ], 
  "Save order": [
    null, 
    "Распоред на зачувување"
  ], 
  "Saving...": [
    null, 
    "Се зачувува..."
  ], 
  "Select a field": [
    null, 
    "Изберете поле"
  ], 
  "Show more": [
    null, 
    "Прикажи повеке"
  ], 
  "Start typing…": [
    null, 
    "Започнете да пишувате…"
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Во овој формулар има незачувани модификации"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Нема API податоци да се вчитаат за овој ресурс"
  ], 
  "URL": [
    null, 
    "УРЛ"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Не може да се автентицира прикачувањето"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Не може да се добијат податоци за прикачената датотека"
  ], 
  "Unable to upload file": [
    null, 
    "Не може да се прикачи датотеката"
  ], 
  "Unfollow": [
    null, 
    "Одследете"
  ], 
  "Upload": [
    null, 
    "Прикачете"
  ], 
  "Upload a file": [
    null, 
    "Прикачете датотека"
  ], 
  "Upload a file on your computer": [
    null, 
    "Прикачете датотека на вашиот компјутер"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "Прикачувате датотека. Дали сте сигурни дека сакате да отидете и да престанете со прикачувањето?"
  ], 
  "bar": [
    "bars", 
    "бар", 
    "бар"
  ], 
  "error loading view": [
    null, 
    "грешка при вчитување на приказ"
  ], 
  "foo": [
    null, 
    "фоо"
  ], 
  "hello %(name)s!": [
    null, 
    "здраво %(name)s"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "нема %(attr)sпревод", 
    "нема %(attr)sпреводи"
  ], 
  "no translation": [
    "no translations", 
    "нема превод", 
    "нема преводи"
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/mk.js <==
{
  "": {
    "domain": "ckan",
    "lang": "mk",
    "plural-forms": "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;"
  },
  "Add Filter": [
    null,
    "Додади филтер"
  ],
  "An Error Occurred": [
    null,
    "Се појави грешка"
  ],
  "An error occured during AJAX request. Could not load view.": [
    null,
    "Предизвикана е греша за време на АЈАХ повикот. Не може да се вчита прегледот"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Дали сте сигурни дека сакате да ја извршите оваа активност?"
  ],
  "Cancel": [
    null,
    "Откажете"
  ],
  "Confirm": [
    null,
    "Потврди"
  ],
  "Could not load view": [
    null,
    "Не може да се вчита приказ"
  ],
  "DataProxy returned an error": [
    null,
    "Податочното прокси врати грешка"
  ],
  "DataStore returned an error": [
    null,
    "Податочното складиште врати грешка"
  ],
  "Edit": [
    null,
    "Уредете"
  ],
  "Failed to load data API information": [
    null,
    "Не успеаа да се вчитаат информациите за API на податоци"
  ],
  "File": [
    null,
    "Датотека"
  ],
  "Filters": [
    null,
    "Филтри"
  ],
  "Follow": [
    null,
    "Следете"
  ],
  "Graph": [
    null,
    "График"
  ],
  "Grid": [
    null,
    "Мрежа"
  ],
  "Hide": [
    null,
    "Сокријте"
  ],
  "Image": [
    null,
    "Слика"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "Влезот е премногу краток, мора да биде најмалку еден знак",
    "Влезот е премногу краток, мора да биде најмалку %(num)d знак"
  ],
  "Link": [
    null,
    "Линк"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Поврзете со линк на интернет (исто така можете да поврзете со API)"
  ],
  "Loading...": [
    null,
    "Се вчитува..."
  ],
  "Map": [
    null,
    "Мапа"
  ],
  "No matches found": [
    null,
    "Не се пронајдени совпаѓања"
  ],
  "Please Confirm Action": [
    null,
    "Ве молиме потврдете ја активноста"
  ],
  "Remove": [
    null,
    "Избриши"
  ],
  "Resource uploaded": [
    null,
    "Ресурсот е прикачен"
  ],
  "Save order": [
    null,
    "Распоред на зачувување"
  ],
  "Saving...": [
    null,
    "Се зачувува..."
  ],
  "Select a field": [
    null,
    "Изберете поле"
  ],
  "Show more": [
    null,
    "Прикажи повеке"
  ],
  "Start typing…": [
    null,
    "Започнете да пишувате…"
  ],
  "There are unsaved modifications to this form": [
    null,
    "Во овој формулар има незачувани модификации"
  ],
  "There is no API data to load for this resource": [
    null,
    "Нема API податоци да се вчитаат за овој ресурс"
  ],
  "URL": [
    null,
    "УРЛ"
  ],
  "Unable to authenticate upload": [
    null,
    "Не може да се автентицира прикачувањето"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Не може да се добијат податоци за прикачената датотека"
  ],
  "Unable to upload file": [
    null,
    "Не може да се прикачи датотеката"
  ],
  "Unfollow": [
    null,
    "Одследете"
  ],
  "Upload": [
    null,
    "Прикачете"
  ],
  "Upload a file": [
    null,
    "Прикачете датотека"
  ],
  "Upload a file on your computer": [
    null,
    "Прикачете датотека на вашиот компјутер"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Прикачувате датотека. Дали сте сигурни дека сакате да отидете и да престанете со прикачувањето?"
  ],
  "error loading view": [
    null,
    "грешка при вчитување на приказ"
  ]
}
